==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Nazwa bloku:
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
&amp;Typ pola:</translatorcomment>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+190"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">* Różni *</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation type="unfinished">:</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">No Selection</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmodyfikuj właściwości obiektu i geometrię
Edytuj geometrię obiektu</translatorcomment>
        <translation type="unfinished">Geometria</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation type="unfinished">Niestandardowy</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Indeks
Uaktualnianie indeksu wyszukiwawczego</translatorcomment>
        <translation type="unfinished">Indeks</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+31"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Sąsiadująco w poziomie
Sąsiadująco w poziomie
Czy chcesz zamknąć plik
%1?</translatorcomment>
        <translation type="unfinished">Wszystkie</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Add custom property to selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wyrównany
&amp;Wyrównany</translatorcomment>
        <translation type="obsolete">Wyrównany</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Rozmieść na stronie
Dopasuj szerokość
Dopasuj stronę</translatorcomment>
        <translation type="obsolete">Dopasować</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rysuj łuki styczne do  obiektu podstawowego
Zaznacz obiekt podstawowy</translatorcomment>
        <translation type="obsolete">Podstawa</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation type="unfinished">Automatycznie</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj automatycznego pomiaru</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Tak
&amp;Tak</translatorcomment>
        <translation type="unfinished">Tak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Nie można otworzyć pliku %1. Proszę sprawdzić prawa.
Nie można otworzyć pliku %1. Proszę sprawdzić prawa
Nie można zapisać pliku %1. Proszę sprawdzić prawa.</translatorcomment>
        <translation type="unfinished">Nie</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Edytor właściwości
Skonfiguruj edytor właściwości</translatorcomment>
        <translation type="unfinished">Edytor właściwości</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation type="unfinished">Wybrane strony:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="unfinished">Ogólny</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przenieś zaznaczenie do nowej warstwy</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Uchwyt:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Nazwa bloku:
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Typ linii:
&amp;Typ pola:</translatorcomment>
        <translation type="obsolete">Typ:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1318"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">* Różni *</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--
Załadowany dokument:
Wersja: </translatorcomment>
        <translation type="unfinished">:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">No Selection</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmodyfikuj właściwości obiektu i geometrię
Edytuj geometrię obiektu</translatorcomment>
        <translation type="obsolete">Geometria</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Niestandardowe..
Niestandardowy
Własne filtry</translatorcomment>
        <translation type="unfinished">Niestandardowy</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Indeks
Uaktualnianie indeksu wyszukiwawczego</translatorcomment>
        <translation type="unfinished">Indeks</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
&amp;Sąsiadująco w poziomie
Sąsiadująco w poziomie
Czy chcesz zamknąć plik
%1?</translatorcomment>
        <translation type="unfinished">Wszystkie</translation>
    </message>
    <message>
        <location line="+639"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dodaj niestandardowy obiekt</translation>
    </message>
    <message>
        <location line="-617"/>
        <source>Add custom property to selected objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - lewo
Środek - lewo</translatorcomment>
        <translation type="obsolete">Lewo</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Góra - prawo
Środek - prawo</translatorcomment>
        <translation type="obsolete">Prawo</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wyrównany
&amp;Wyrównany</translatorcomment>
        <translation type="obsolete">Wyrównany</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="obsolete">Środek</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--google--
Rozmieść na stronie
Dopasuj szerokość
Dopasuj stronę</translatorcomment>
        <translation type="obsolete">Dopasować</translation>
    </message>
    <message>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Upuść aby zakończyć przesuwanie widoku
Góra - prawo</translatorcomment>
        <translation type="obsolete">Do góry</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Rysuj łuki styczne do  obiektu podstawowego
Zaznacz obiekt podstawowy</translatorcomment>
        <translation type="obsolete">Podstawa</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Dół - lewo
Dół - prawo</translatorcomment>
        <translation type="obsolete">W dół</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation type="unfinished">Automatycznie</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj automatycznego pomiaru</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Tak
&amp;Tak</translatorcomment>
        <translation type="unfinished">Tak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Nie można otworzyć pliku %1. Proszę sprawdzić prawa.
Nie można otworzyć pliku %1. Proszę sprawdzić prawa
Nie można zapisać pliku %1. Proszę sprawdzić prawa.</translatorcomment>
        <translation type="unfinished">Nie</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Edytor właściwości
Skonfiguruj edytor właściwości</translatorcomment>
        <translation type="unfinished">Edytor właściwości</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_pl.ts--</translatorcomment>
        <translation type="unfinished">Wybrane strony:</translation>
    </message>
    <message>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="obsolete">Ogólny</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Przenieś zaznaczenie do nowej warstwy</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Uchwyt:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
